@@ -6,7 +6,7 @@
 
 class KGpgDelKeyTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testDeleteKey();
 	void testDeleteKey_data();
